views Package
=============

:mod:`views` Package
--------------------

.. automodule:: masai.views
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mpl` Module
-----------------

.. automodule:: masai.views.mpl
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`plot_editor` Module
-------------------------

.. automodule:: masai.views.plot_editor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`viewplot` Module
----------------------

.. automodule:: masai.views.viewplot
    :members:
    :undoc-members:
    :show-inheritance:

